==> u61-0.2.0.tar.gz: u61-0.2.0/script/package/couple.lua <==
------------------------------------------------------------------------------
--                                                                          --
-- U U    6   1            U U   FFF  O   O  TTT                            --
-- U U   6   11   b        U U   F   O O O O  T                             --
-- U U - 66   1   bb  y y  U U - FF  O O O O  T                             --
-- U U   6 6  1   b b  y   U U   F   O O O O  T                             --
--  U     6   1   bb   y    U    F    O   O   T                             --
--                                                                          --
-- U61 is another block based game                                          --
-- Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   --
--                                                                          --
-- This program is free software; you can redistribute it and/or            --
-- modify it under the terms of the GNU General Public License              --
-- as published by the Free Software Foundation; either version 2           --
-- of the License, or (at your option) any later version.                   --
--                                                                          --
-- This program is distributed in the hope that it will be useful,          --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of           --
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            --
-- GNU General Public License for more details.                             --
--                                                                          --
-- You should have received a copy of the GNU General Public License        --
-- along with this program; if not, write to the Free Software              --
-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA--
--                                                                          --
-- This project is also available on SourceForge  (http://sourceforge.net)  --
------------------------------------------------------------------------------

-- couple game, you have blocks with two squares of different colors, it's
-- possible to translate and rotate them, and one need to have 4 adjacent
-- squares (at least) of the same color to make them disappear 


-- shape definition ----------------------------------------------------------

function user_block_shape(num)
    vertical_colored_bar(2,num)
end


-- actions -------------------------------------------------------------------

function user_block_rotate_left()
    block_geometric_rotate_left()    
end

function user_block_rotate_right()
    block_geometric_rotate_right()    
end

function user_block_move_left()
    block_translate_x(-1)
end

function user_block_move_right()
    block_translate_x(1)
end

function user_block_move_down()
    block_translate_y(1)
end


-- pattern match -------------------------------------------------------------

function user_map_match_pattern()
    return 0
end

function user_block_land()
    block_split()
end

function user_map_square_blown_up(x,y)
    column_down(x,y)
end

-- other functions -----------------------------------------------------------

function user_map_time_callback()
    u61_map_add_score(1)
end

==> u61-1.1.0.tar.gz: u61-1.1.0/script/package/couple.lua <==
------------------------------------------------------------------------------
--                                                                          --
-- U U    6   1            U U   FFF  O   O  TTT                            --
-- U U   6   11   b        U U   F   O O O O  T                             --
-- U U - 66   1   bb  y y  U U - FF  O O O O  T                             --
-- U U   6 6  1   b b  y   U U   F   O O O O  T                             --
--  U     6   1   bb   y    U    F    O   O   T                             --
--                                                                          --
-- U61 is another block based game                                          --
-- Copyright (C) 2000-2003 Christian Mauduit (ufoot@ufoot.org)              --
--                                                                          --
-- This program is free software; you can redistribute it and/or            --
-- modify it under the terms of the GNU General Public License              --
-- as published by the Free Software Foundation; either version 2           --
-- of the License, or (at your option) any later version.                   --
--                                                                          --
-- This program is distributed in the hope that it will be useful,          --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of           --
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            --
-- GNU General Public License for more details.                             --
--                                                                          --
-- You should have received a copy of the GNU General Public License        --
-- along with this program; if not, write to the Free Software              --
-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA--
--                                                                          --
-- This project is also available on Savannah (http://savannah.gnu.org)     --
------------------------------------------------------------------------------

-- couple game, you have blocks with two squares of different colors, it's
-- possible to translate and rotate them, and one need to have 4 adjacent
-- squares (at least) of the same color to make them disappear 


-- initialization ------------------------------------------------------------

function user_start()
    u61_set_height(20)
    u61_set_width(6)
end


-- shape definition ----------------------------------------------------------

function user_new_shape(num)
    return num
end 

function user_do_shape(num)
    colored_vertical_bar(2,6,num)
end


-- actions -------------------------------------------------------------------

function user_rotate_left()
    rotation_left()    
end

function user_rotate_right()
    rotation_right()    
end

function user_move_left()
    translation_x(-1)
end

function user_move_right()
    translation_x(1)
end

function user_move_down()
    translation_y(1)
end

function user_use_antidote()
    u61_cancel_curse(u61_get_oldest_curse(0))
end

-- pattern match -------------------------------------------------------------

function user_match_pattern(match_count)
    return connected_match_pattern(match_count,4)
end

function user_land()
    split_block()
end

function user_square_blown_up(x,y)
    utils_shift_column_down(x,y)
end

-- curse functions  ----------------------------------------------------------

function user_new_curse(num)
    num=mod(num,4)

    return num
end

function user_do_curse(num,sent)

end

function user_get_curse_name(num)
    name="todo..."

    return name
end

-- callback functions --------------------------------------------------------

function user_time_callback_1()
    u61_add_score(1)
end

function user_time_callback_10()

end

function user_time_callback_100()

end
